Struct PeekMut

pub struct PeekMut<'a, T> { /* private fields */ }
🔬This is a nightly-only experimental API. (vec_peek_mut)
Available on crate feature wayland and Linux only.
Structure wrapping a mutable reference to the last item in a Vec.

This struct is created by the peek_mut method on Vec. See its documentation for more.

Implementations

Source

impl<'a, T> PeekMut<'a, T>

pub fn pop(self) -> T

🔬This is a nightly-only experimental API. (vec_peek_mut)

Removes the peeked value from the vector and returns it.